@@ -1,15 +1,17 @@
 package HackaMol::Roles::MolReadRole;
-$HackaMol::Roles::MolReadRole::VERSION = '0.026';
+$HackaMol::Roles::MolReadRole::VERSION = '0.027';
 # ABSTRACT: Read files with molecular information
 use Moose::Role;
 use Carp;
 use Math::Vector::Real;
 use HackaMol::PeriodicTable qw(%KNOWN_NAMES);
 use FileHandle;
+use YAML::XS qw(LoadFile);
 use HackaMol::Atom;    #add the code,the Role may better to understand
 use List::MoreUtils qw(singleton);
 
 with qw(
+        HackaMol::Roles::ReadYAMLRole
         HackaMol::Roles::ReadZmatRole
         HackaMol::Roles::ReadPdbRole
         HackaMol::Roles::ReadPdbqtRole
@@ -26,19 +28,27 @@ has 'hush_read' => (
 sub read_file_atoms {
     my $self = shift;
     my $file = shift;
+    my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
+
     my @atoms;
 
+
     if ( $file =~ m/\.pdb$/ ) {
-        @atoms = $self->read_pdb_atoms($file);
+        @atoms = $self->read_pdb_atoms($fh);
     }
     elsif ( $file =~ m/\.pdbqt$/ ) {
-        @atoms = $self->read_pdbqt_atoms($file);
+        @atoms = $self->read_pdbqt_atoms($fh);
     }
     elsif ( $file =~ m/\.xyz$/ ) {
-        @atoms = $self->read_xyz_atoms($file);
+        @atoms = $self->read_xyz_atoms($fh);
     }
     elsif ( $file =~ m/\.zmat$/ ) {
-        @atoms = $self->read_zmat_atoms($file);
+        @atoms = $self->read_zmat_atoms($fh);
+    }
+    elsif ( $file =~ m/\.yaml$/) {
+        $fh->close;
+        $fh = LoadFile($file); 
+        @atoms = $self->read_yaml_atoms($fh);
     }
     else {
         croak "$file format not supported";
@@ -60,7 +70,7 @@ HackaMol::Roles::MolReadRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
@@ -155,9 +165,11 @@ L<HackaMol::Molecule>
 
 =item * L<HackaMol::Roles::ReadXyzRole>
 
-=item * L<HackaMol::Roles::ReadZmatRole>
+=item * L<HackaMol::Roles::ReadYAMLRole>
 
-=item * L<HackaMol::Roles::ReadZmatRole|HackaMol::Roles::ReadPdbRole|HackaMol::Roles::ReadPdbqtRole|HackaMol::Roles::ReadXyzRole>
+=item * L<HackaMol::Roles::ReadYAMLRole|HackaMol::Roles::ReadZmatRole|HackaMol::Roles::ReadPdbRole|HackaMol::Roles::ReadPdbqtRole|HackaMol::Roles::ReadXyzRole>
+
+=item * L<HackaMol::Roles::ReadZmatRole>
 
 =back
 
