@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadPdbRole;
-$HackaMol::Roles::ReadPdbRole::VERSION = '0.026';
+$HackaMol::Roles::ReadPdbRole::VERSION = '0.027';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
@@ -11,8 +11,9 @@ sub read_pdb_atoms {
 
     #read pdb file and generate list of Atom objects
     my $self = shift;
-    my $file = shift;
-    my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
+    my $fh   = shift;
+    #my $file = shift;
+    #my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
 
     my @atoms;
     my ( $n, $t ) = ( 0, 0 );
@@ -124,7 +125,7 @@ HackaMol::Roles::ReadPdbRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
