@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadPdbqtRole;
-$HackaMol::Roles::ReadPdbqtRole::VERSION = '0.026';
+$HackaMol::Roles::ReadPdbqtRole::VERSION = '0.027';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
@@ -11,9 +11,9 @@ sub read_pdbqt_atoms {
 
  # this is too similar to reading pdb for it too exist separately... think about
     my $self = shift;
-    my $file = shift;
-
-    my $fh = FileHandle->new("<$file") or croak "unable to open $file";
+    my $fh   = shift;
+    #my $file = shift;
+    #my $fh = FileHandle->new("<$file") or croak "unable to open $file";
 
 # $RtBrnch{ROOT}{iatoms}    = LIST integers of atoms in root
 # $RtBrnch{BRNCH1}{iatoms}  = LIST integers of atoms in BRNCH1
@@ -130,7 +130,7 @@ HackaMol::Roles::ReadPdbqtRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
