@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadXyzRole;
-$HackaMol::Roles::ReadXyzRole::VERSION = '0.026';
+$HackaMol::Roles::ReadXyzRole::VERSION = '0.027';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2; 
@@ -11,8 +11,9 @@ sub read_xyz_atoms {
 
     #read xyz file and generate list of Atom objects
     my $self = shift;
-    my $file = shift;
-    my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
+    my $fh   = shift;
+ #   my $file = shift;
+ #   my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
 
     my @atoms;
     my ( $n, $t ) = ( 0, 0 );
@@ -82,7 +83,7 @@ HackaMol::Roles::ReadXyzRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
