@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadZmatRole;
-$HackaMol::Roles::ReadZmatRole::VERSION = '0.026';
+$HackaMol::Roles::ReadZmatRole::VERSION = '0.027';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
@@ -16,8 +16,9 @@ sub read_zmat_atoms {
 
     #xyz file and generate list of Atom object
     my $self = shift;
-    my $file = shift;
-    my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
+    my $fh   = shift;
+#    my $file = shift;
+#    my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
 
     my @atoms;
     my ( $n, $t ) = ( 0, 0 );
@@ -169,7 +170,7 @@ HackaMol::Roles::ReadZmatRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
